package com.dcsoft.system.face.service.impl;

import java.util.List;
import com.dcsoft.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.dcsoft.system.face.mapper.SysAuthMapper;
import com.dcsoft.system.api.domain.SysAuth;
import com.dcsoft.system.face.service.ISysAuthService;

/**
 * 认证数据Service业务层处理
 *
 * @author nichun
 * @date 2023-03-29
 */
@Service
public class SysAuthServiceImpl implements ISysAuthService
{
    @Autowired
    private SysAuthMapper sysAuthMapper;

    /**
     * 查询认证数据
     *
     * @param appKey 认证数据主键
     * @return 认证数据
     */
    @Override
    public SysAuth selectSysAuthById(String appKey)
    {
        return sysAuthMapper.selectSysAuthById(appKey);
    }

    /**
     * 查询认证数据列表
     *
     * @param sysAuth 认证数据
     * @return 认证数据
     */
    @Override
    public List<SysAuth> selectSysAuthList(SysAuth sysAuth)
    {
        return sysAuthMapper.selectSysAuthList(sysAuth);
    }

    /**
     * 新增认证数据
     *
     * @param sysAuth 认证数据
     * @return 结果
     */
    @Override
    public int insertSysAuth(SysAuth sysAuth)
    {
        sysAuth.setCreateTime(DateUtils.getNowDate());
        return sysAuthMapper.insertSysAuth(sysAuth);
    }

    /**
     * 修改认证数据
     *
     * @param sysAuth 认证数据
     * @return 结果
     */
    @Override
    public int updateSysAuth(SysAuth sysAuth)
    {
        sysAuth.setUpdateTime(DateUtils.getNowDate());
        return sysAuthMapper.updateSysAuth(sysAuth);
    }

    /**
     * 批量删除认证数据
     *
     * @param ids 需要删除的认证数据主键
     * @return 结果
     */
    @Override
    public int deleteSysAuthByIds(Long[] ids)
    {
        return sysAuthMapper.deleteSysAuthByIds(ids);
    }

    /**
     * 删除认证数据信息
     *
     * @param id 认证数据主键
     * @return 结果
     */
    @Override
    public int deleteSysAuthById(Long id)
    {
        return sysAuthMapper.deleteSysAuthById(id);
    }
}
